@@ -3,7 +3,7 @@ package Apache2::ASP::Base;
 
 use strict;
 use warnings 'all';
-use CGI ();
+use CGI::Simple ();
 
 use Apache2::ASP::PageHandler;
 use Apache2::ASP::Request;
@@ -31,7 +31,7 @@ sub setup_request
   my ($s, $r, $q) = @_;
   # Init self:
   $s->{r}           = $r;
-  $s->{q}           = $q ? $q : CGI->new();
+  $s->{q}           = $q ? $q : CGI::Simple->new();
   $s->{request}     = Apache2::ASP::Request->new( $s );
   $s->{response}    = Apache2::ASP::Response->new( $s );
   $s->{server}      = Apache2::ASP::Server->new( $s );
